@@ -6,12 +6,13 @@ use 5.008;
 
 use Padre::Wx::Dialog::Preferences ();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our @ISA     = 'Padre::Wx::Dialog::Preferences';
 
 sub panel {
 	my $self     = shift;
 	my $treebook = shift;
+	my $parent   = shift;
 
 	my $config = Padre->ide->config;
 
@@ -31,7 +32,7 @@ sub panel {
 	];
 
 	my $panel = $self->_new_panel($treebook);
-	$self->fill_panel_by_table( $panel, $table );
+	$parent->fill_panel_by_table( $panel, $table );
 
 	return $panel;
 }
@@ -63,6 +64,12 @@ __END__
 
 Padre::Plugin::PHP - L<Padre> and PHP
 
+=head1 DESCRIPTION
+
+This modules provides preference options for the Padre::Plugin::PHP - module.
+
+It uses the Padre preferences panel.
+
 =head1 AUTHOR
 
 Sebastian Willing
